## ---- initialize

set.seed(31415)         # Pour la reroductibilité: initialise le générateur de nombres pseudo-aléatoires

require("knitr")

## ---- knitgroup

## Fonction pour compiler une question répliquée

# questioname est le nom de la question contenue dans un fichier questioname.rnw (une seule question par fichier)
# questionindex est l'indice de la fonction dans le groupe de questions générées par R

knitgroup <- function(questionname, questionindex=1) {
  rnwfile <- sprintf("sources_amc/rnw/%s.rnw", questionname)
  texfile <- sprintf("sources_amc/r-generated/knitr-%s-%03d.tex",questionname, questionindex)
  # Redirige les sorties de R vers un nouveau type de nom de fichier pour créer des fichiers différents pour les questions d'un même groupe
  opts_chunk$set(fig.path=sprintf("sources_amc/r-generated/knitr-%s-%03d-",questionname, questionindex))
  # Récupère l'environnement courant et son parent
  envir <- environment()
  parent.env(envir) <- parent.frame()
  # Compile la question dans l'environnement ainsi créé
  knit(input=rnwfile, output=texfile, envir=envir,quiet=TRUE)
  # Réinitialise le nom de base pour les sorties de R
  opts_chunk$set(fig.path="sources_amc/r-generated/knitr-")
  # Insère une ligne d'input dans le fichier .tex principal
  cat(sprintf("\\input{%s}\n",texfile))
}

## ---- GroupeExemple

for(qindex in 1:4) {
  # Ces valeurs aléatoires seront utilisés dans les questions suivantes

  n <- 50
  x <- floor(runif(n, min=0, max=100))
  y <- rnorm(n, mean=0, sd=20)+x*0.25
  sumx <- sum(x)
  sumy <- sum(y)
  sumx2 <- sum(x^2)
  sumy2 <- sum(y^2)
  sumxy <- sum(x*y)
  xbar <- mean(x)
  s2x <- mean((x-xbar)^2)
  sx <- sqrt(s2x)
  ybar <- mean(y)
  s2y <- mean((y-ybar)^2)
  sy <- sqrt(s2y)
  cor(x,y)
  knitgroup(questionname="simple", questionindex=qindex)
  knitgroup(questionname="multiple", questionindex=qindex)
  knitgroup(questionname="numeric", questionindex=qindex)
}
